@@ -5,9 +5,9 @@ from django.utils import timezone
 from tracking.models import Visitor, Pageview
 from tracking.utils import get_ip_address
 from tracking.settings import (TRACK_AJAX_REQUESTS,
-    TRACK_ANONYMOUS_USERS, TRACK_PAGEVIEWS, TRACK_IGNORE_URLS, TRACK_IGNORE_STATUS_CODES)
+    TRACK_ANONYMOUS_USERS, TRACK_PAGEVIEWS, TRACK_IGNORE_URLS, TRACK_IGNORE_STATUS_CODES, TRACK_REFERER, TRACK_QUERY_STRING)
 
-TRACK_IGNORE_URLS = map(lambda x: re.compile(x), TRACK_IGNORE_URLS)
+TRACK_IGNORE_URLS = [re.compile(x) for x in TRACK_IGNORE_URLS]
 
 log = logging.getLogger(__file__)
 
@@ -46,10 +46,13 @@ class VisitorTrackingMiddleware(object):
         try:
             visitor = Visitor.objects.get(pk=session_key)
         except Visitor.DoesNotExist:
+            visitor_user_agent = request.META.get('HTTP_USER_AGENT', None)
+            if visitor_user_agent is not None:
+                visitor_user_agent = visitor_user_agent.decode('latin-1', errors='ignore')
             # Log the ip address. Start time is managed via the
             # field `default` value
             visitor = Visitor(pk=session_key, ip_address=get_ip_address(request),
-                user_agent=request.META.get('HTTP_USER_AGENT', None))
+                user_agent=visitor_user_agent)
 
         # Update the user field if the visitor user is not set. This
         # implies authentication has occured on this request and now
@@ -79,8 +82,17 @@ class VisitorTrackingMiddleware(object):
                 if url.match(path):
                     break
             else:
+                referer = None
+                query_string = None
+
+                if TRACK_REFERER:
+                    referer = request.META.get('HTTP_REFERER', None)
+
+                if TRACK_QUERY_STRING:
+                    query_string = request.META.get('QUERY_STRING')
+
                 pageview = Pageview(visitor=visitor, url=request.path,
-                    view_time=now, method=request.method)
+                    view_time=now, method=request.method, referer=referer, query_string=query_string)
                 pageview.save()
 
         return response
