@@ -69,7 +69,9 @@ class Visitor(models.Model):
 
 class Pageview(models.Model):
     visitor = models.ForeignKey(Visitor, related_name='pageviews')
-    url = models.CharField(max_length=500)
+    url = models.TextField(null=False, editable=False)
+    referer = models.TextField(null=True, editable=False)
+    query_string = models.TextField(null=True, editable=False)
     method = models.CharField(max_length=20, null=True)
     view_time = models.DateTimeField()
 
