@@ -14,3 +14,7 @@ TRACK_IGNORE_STATUS_CODES = getattr(settings, 'TRACK_IGNORE_STATUS_CODES', [])
 TRACK_USING_GEOIP = getattr(settings, 'TRACK_USING_GEOIP', False)
 if hasattr(settings, 'TRACKING_USE_GEOIP'):
     raise DeprecationWarning('TRACKING_USE_GEOIP has been renamed to TRACK_USING_GEOIP')
+
+TRACK_REFERER = getattr(settings, 'TRACK_REFERER', False)
+
+TRACK_QUERY_STRING = getattr(settings, 'TRACK_QUERY_STRING', False)
\ No newline at end of file
